storesRecord property
Raw stores record returned by the feature's stores factory.
null if the feature has no factory or has not been activated yet.
Implementation
final Object? storesRecord;
Raw stores record returned by the feature's stores factory.
null if the feature has no factory or has not been activated yet.
final Object? storesRecord;