duration property
Quiet window the timer waits for after the most recent call before the function actually fires.
Implementation
final Duration duration;
Quiet window the timer waits for after the most recent call before the function actually fires.
final Duration duration;