edge property

ThrottleEdge edge
final

Which call inside each window fires the function — ThrottleEdge.leading (the first one, immediately) or ThrottleEdge.trailing (the last one, at the end of the window).

Implementation

final ThrottleEdge edge;