value property

TValue get value

Latest apply result. Updated automatically whenever a tracked atom changes or reapply is called. After dispose, returns the value at the last successful apply.

Implementation

TValue get value;