FeatureDebugInfo class
Debug info for a single feature.
Constructors
-
FeatureDebugInfo({required String name, required FeatureStatus status, required List<
PortDebugInfo> ports, required List<FeatureDependency> dependencies, required List<String> childNames, required List<Store< stores, required Object? storesRecord, required Duration? resolveTime})Object?> >
Properties
-
childNames
→ List<
String> -
Names of features that depend on this one (direct children).
final
-
dependencies
→ List<
FeatureDependency> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
ports
→ List<
PortDebugInfo> -
final
- resolveTime → Duration?
-
Time taken by the feature's most recent activation, or
nullif it never activated.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → FeatureStatus
-
final
-
stores
→ List<
Store< Object?> > -
final
- storesRecord → Object?
-
Raw stores record returned by the feature's
storesfactory.nullif the feature has no factory or has not been activated yet.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited