TaskStrategyLatest class final
Supersede-and-share strategy: a new call cancels the in-flight one; all pending callers share the latest run's outcome. See TaskStrategy.latest.
- Inheritance
-
- Object
- TaskStrategy
- TaskStrategyLatest
Constructors
- TaskStrategyLatest()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited