TaskError class final
Thrown when a Task is called after it — or the owning Store —
has been disposed, or surfaced through a pending future when
Task.reset() cancels coalesced callers from .latest,
.debounce, or .throttle(trailing).
- Inheritance
-
- Object
- Error
- ArmatureError
- TaskError
Constructors
- TaskError(String message, {StackTrace? stackTrace})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Captured stack trace — either passed into the constructor (e.g.
threaded through
wrap(..., stackTrace: st)at acatchsite) or, failing that, the trace the VM attached when this error was thrown.nullonly if the error was never thrown and no trace was supplied.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited